#
# spec file for package python-awkward-cpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-awkward-cpp
Version:        30
Release:        1.2
Summary:        CPU kernels and compiled extensions for Awkward Array
License:        BSD-3-Clause
URL:            https://awkward-array.org/
# SourceRepository:  https://github.com/scikit-hep/awkward/awkward-cpp
Source0:        https://files.pythonhosted.org/packages/source/a/awkward-cpp/awkward-cpp-%{version}.tar.gz
Source99:       awkward-cpp.rpmlintrc
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pybind11-devel}
BuildRequires:  %{python_module scikit-build-core-pyproject >= 0.2}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.17.0
Provides:       python-awkward_cpp = %{version}-%{release}
# SECTION test requirements
BuildRequires:  %{python_module numpy >= 1.17.0}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Awkward Array is a library for nested, variable-sized data, including
arbitrary-length lists, records, mixed types, and missing data, using
NumPy-like idioms.

Arrays are dynamically typed, but operations on them are compiled and fast.
Their behavior coincides with NumPy when array dimensions are regular and
generalizes when they're not.

awkward-cpp provides precompiled routines for the awkward package.
It is not useful on its own, only as a dependency for awkward.

%package -n awkward-devel
Summary:        Header files for using awkward in C/C++ code

%description -n awkward-devel
Awkward Array is a library for nested, variable-sized data, including
arbitrary-length lists, records, mixed types, and missing data, using
NumPy-like idioms.

This package provides the header files needed to compile C/C++ codes with
awkward.

%prep
%setup -q -n awkward-cpp-%{version}

%build
%pyproject_wheel
%cmake -S ../header-only
%cmake_build

%install
%pyproject_install
%cmake_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/awkward_cpp
%{python_sitearch}/awkward_cpp-%{version}.dist-info

%files -n awkward-devel
%doc README.md
%license LICENSE
%{_includedir}/builder-options
%{_includedir}/growable-buffer
%{_includedir}/layout-builder
%{_libdir}/cmake/awkward-headers

%changelog
* Mon Mar 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 30:
  * No changelog available.
* Mon Jan 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 28:
  * No changelog available.
* Fri Dec 15 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 27:
  * Remove obsolete cuda_kernels (gh#scikit-hep/awkward#2876).
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- update to 26:
  * Keep Document value unchanged on parse error (#439)
  * Add missing return statement (#450)
  * Fix Document::Parse(const Ch*) for transcoding (#478)
  * encodings.h: fix typo in preprocessor condition (#495)
  * Custom Microsoft headers are necessary only for Visual Studio
    2012 and lower (#559)
  * Fix memory leak for invalid regex
    (26e69ffde95ba4773ab06db6457b78f308716f4b)
  * Fix a bug in schema minimum/maximum keywords for 64-bit
    integer (e7149d665941068ccf8c565e77495521331cf390)
  * Fix a crash bug in regex (#605)
  * Fix schema "required" keyword cannot handle duplicated keys
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- update to 24:
  * CMakeLists for include as a thirdparty in projects
  * Change Document::ParseStream() to use stack allocator for
    Reader
* Sun Sep 17 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 23:
  * refactor: set flags on targets
  * fix: restore std
  * fix: drop more references to CXX_EXTENSIONS et al.
* Mon Sep 11 2023 Dirk Müller <dmueller@suse.com>
- update to 22:
  * Add iostream wrapper (#530)
  * Add Jsonx example for converting JSON into JSONx (a XML
    format) (#531)
  * Add optional unresolvedTokenIndex parameter to Pointer::Get()
    (#532)
  * Add encoding validation option for Writer/PrettyWriter (#534)
  * Add Writer::SetMaxDecimalPlaces() (#536)
  * Support {0, } and {0, m} in Regex (#539)
  * Add Value::Get/SetFloat(), Value::IsLossLessFloat/Double()
    (#540)
  * Add stream position check to reader unit tests (#541)
  * Add Templated accessors and range-based for (#542)
  * Add (Pretty)Writer::RawValue() (#543)
  * Add Document::Parse(std::string), Document::Parse(const
    char*, size_t length) and related APIs. (#553)
  * Add move constructor for GenericSchemaDocument (#554)
  * Add VS2010 and VS2015 to AppVeyor CI (#555)
  * Add parse-by-parts example (#556, #562)
  * Support parse number as string (#564, #589)
  * Add kFormatSingleLineArray for PrettyWriter (#577)
  * Added optional support for trailing commas (#584)
  * Added filterkey and filterkeydom examples (#615)
  * Added npm docs (#639)
  * Allow options for writing and parsing NaN/Infinity (#641)
  * Add std::string overload to PrettyWriter::Key() when
    RAPIDJSON_HAS_STDSTRING is defined (#698)
* Thu Jul 27 2023 Dirk Müller <dmueller@suse.com>
- mark as python311 on sle15 as it requires >= 3.8
* Mon Jul 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21:
  * Bug fix: added kernel specializations for
    awkward_ListOffsetArray_reduce_local_nextparents_64
    [gh#scikit-hep/awkward#2572].
- Now requires python >= 3.8.
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 18:
  * update pyodide parts a bit
* Tue Jun 20 2023 Dirk Müller <dmueller@suse.com>
- update to 17:
  * Make GenericSchemaDocument constructor explicit (#674)
  * Optimize FindMember when use std::string (#690)
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 16:
  * Add GenericDocument ctor overload to specify JSON type (#369)
  * Add FAQ (#372, #373, #374, #376)
  * Add forward declaration header `fwd.h`
  * Add @PlatformIO Library Registry manifest file (#400)
  * Implement assignment operator for BigInteger (#404)
  * Add comments support (#443)
  * Adding coapp definition (#460)
  * documenttest.cpp: EXPECT_THROW when checking empty allocator
    (470)
  * GenericDocument: add implicit conversion to ParseResult
    (#480)
  * Use <wchar.h> with C++ linkage on Windows ARM (#485)
  * Detect little endian for Microsoft ARM targets
  * Check Nan/Inf when writing a double (#510)
  * Add JSON Schema Implementation (#522)
  * Add iostream wrapper (#530)
  * Add Jsonx example for converting JSON into JSONx (a XML
    format) (#531)
  * Add optional unresolvedTokenIndex parameter to Pointer::Get()
    (#532)
  * Add encoding validation option for Writer/PrettyWriter (#534)
  * Add Writer::SetMaxDecimalPlaces() (#536)
  * Support {0, } and {0, m} in Regex (#539)
  * Add Value::Get/SetFloat(), Value::IsLossLessFloat/Double()
    (#540)
  * Add stream position check to reader unit tests (#541)
  * Add Templated accessors and range-based for (#542)
  * Add (Pretty)Writer::RawValue() (#543)
  * Add Document::Parse(std::string), Document::Parse(const
    char*, size_t length) and related APIs. (#553)
  * Add move constructor for GenericSchemaDocument (#554)
  * Add VS2010 and VS2015 to AppVeyor CI (#555)
  * Add parse-by-parts example (#556, #562)
  * Support parse number as string (#564, #589)
  * Add kFormatSingleLineArray for PrettyWriter (#577)
  * Added optional support for trailing commas (#584)
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 15:
  * Add parse-by-parts example (#556, #562)
  * Support parse number as string (#564, #589)
  * Add kFormatSingleLineArray for PrettyWriter (#577)
  * Added optional support for trailing commas (#584)
  * Added filterkey and filterkeydom examples (#615)
  * Added npm docs (#639)
  * Allow options for writing and parsing NaN/Infinity (#641)
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 8:
  * Add GenericDocument ctor overload to specify JSON type
  * Add FAQ
  * Add forward declaration header `fwd.h`
  * Add @PlatformIO Library Registry manifest file
  * Implement assignment operator for BigInteger
  * Add comments support
  * Adding coapp definition
  * documenttest.cpp: EXPECT_THROW when checking empty allocator
  * GenericDocument: add implicit conversion to ParseResult
  * Use <wchar.h> with C++ linkage on Windows ARM
  * Detect little endian for Microsoft ARM targets
  * Check Nan/Inf when writing a double
  * Add JSON Schema Implementation
  * Add iostream wrapper
  * Add Jsonx example for converting JSON into JSONx (a XML
    format)
  * Add optional unresolvedTokenIndex parameter to Pointer::Get()
  * Add encoding validation option for Writer/PrettyWriter
  * Add Writer::SetMaxDecimalPlaces()
  * Support {0, } and {0, m} in Regex
  * Add Value::Get/SetFloat(), Value::IsLossLessFloat/Double()
  * Add stream position check to reader unit tests
  * Add Templated accessors and range-based for
  * Add (Pretty)Writer::RawValue()
  * Add Document::Parse(std::string), Document::Parse(const
    char*, size_t length) and related APIs.
  * Add move constructor for GenericSchemaDocument
  * Add VS2010 and VS2015 to AppVeyor CI
  * Add parse-by-parts example
  * Support parse number as string
* Fri Jan 27 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v7
- Required by awkward 2
